@@ -1,6 +1,7 @@
 package File::DataClass::Constants;
 
-use strictures;
+use strict;
+use warnings;
 
 use Exporter 5.57 qw( import );
 use File::DataClass::Exception;
@@ -175,7 +176,7 @@ Patches are welcome
 
 =head1 Author
 
-Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
+Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
